import { Injectable } from "@nestjs/common";
import { ObjectType, ArgsType, Field } from "@nestjs/graphql";
import { Observable, of } from "rxjs";
import * as fs from 'graceful-fs';
import { converter } from "./Fis-GraphQLQueryGenerator/GraphQLTypescriptConverter/GraphQLTypescriptConverter";
import { DefaultQueryData as DefaultQueryDataType } from "../message/fisappmessagejsutility/interface/export";
import { DefaultQueryDataItem as DefaultQueryDataItemType } from "../message/fisappmessagejsutility/interface/export";
 
@ObjectType()
@ArgsType()
export class DefaultQueryData implements DefaultQueryDataType {

    @Field(type => [DefaultQueryDataItem])
    data: DefaultQueryDataItem[];
}

@ObjectType()
@ArgsType()
export class DefaultQueryDataItem implements DefaultQueryDataItemType {
    @Field()
    queryName: string

    @Field()
    queryString: string
}

@Injectable()
export class DefaultQueryService {

    defaultQueryDatas: DefaultQueryData

    constructor() {
        converter();

        const directoryPath = fs.readdirSync('./src/FisAppQueryModule/DefaultQuery/Fis-GraphQLQueryGenerator/GraphQLConverted', 'utf8');
        let arrayItems = [];
        directoryPath.forEach(file => {
            
            let data: DefaultQueryDataItem = {
                queryName: file.split('.')[0],
                queryString: fs.readFileSync('./src/FisAppQueryModule/DefaultQuery/Fis-GraphQLQueryGenerator/GraphQLConverted/' + file, 'utf8')
            }

            arrayItems.push(data)

        })
        
        this.defaultQueryDatas = {data: arrayItems}

    }

    GetDefaultQuery(): Observable<DefaultQueryData> {
        
        return of(this.defaultQueryDatas);
    }
}