import { HttpService } from '@nestjs/axios';
import { Injectable } from '@nestjs/common';
import { from, of, Observable, Subject } from 'rxjs';
// import { FisUASRequestMessage } from '../FisAppQueryModule/message/fis.request.message';
import { AccountProfileDataService } from './DS/AccountProfile.dataservice';
// import { AccountProfileDataService } from './DS/AccountProfile.dataservice';
import { APAccountProfileDataService } from './DS/APAccountProfile.dataservice';
import { APInvoiceDocumentDataService } from './DS/APInvoiceDocument.dataservice';
import { APReceiptDocumentDataService } from './DS/APReceiptDocument.dataservice';
// import { APReceiptDocumentDataService } from './DS/APReceiptDocument.dataservice';
import { ARAccountProfileDataService } from './DS/ARAccountProfile.dataservice';
import { ARInvoiceDocumentDataService } from './DS/ARInvoiceDocument.dataservice';
import { ARReceiptDocumentDataService } from './DS/ARReceiptDocument.dataservice';
// import { ARReceiptDocumentDataService } from './DS/ARReceiptDocument.dataservice';
import { CMAccountProfileDataService } from './DS/CMAccountProfile.dataservice';
import { CommonDataService } from './DS/Common.dataservice';
import { DocumentDataService } from './DS/Document.dataservice';
import { FisServiceProgramProfileDataService } from './DS/FisServiceProgramProfile.dataservice';
import { LeaveBalanceDataService } from './DS/LeaveBalance.dataservice';
import { LeaveHistoryDataService } from './DS/LeaveHistory.dataservice';
import { LeaveTypeProfileDataService } from './DS/LeaveTypeProfile.dataservice';
import { OrganisationProfileDataService } from './DS/OrganisationProfile.dataservice';
import { ProductProfileDataService } from './DS/ProductProfile.dataservice';
import { RoleTypeProfileDataService } from './DS/RoleTypeProfileDataService';
import { ServiceProgramProfileDataService } from './DS/ServiceProgramProfile.dataservice';
import { AppMessageType, BaseMessage, FisCreateMessageUtility, ResponseExceptionMessage, ResponseMessage, Uuid } from './message/fisappmessagejsutility/interface/export';
import * as fs from 'graceful-fs';
import { DomainProxyController } from '../common-service-channel/DomainProxy/src/services/DP.controller';
import { ConnectionInterface } from '../common-service-channel/DomainProxy/src/interface/DP.Connection.interface';
import { IPs } from './GetIPAddress';
import { FFBProductionDataService } from './DS/FFBProduction.dataservice';
import { FFBProductionSummaryDataService } from './DS/FFBProductionSummary.dataservice';

@Injectable()
export class DataServiceManager {

    static ucpId: string;
    static ResponseService: FisCreateMessageUtility = new FisCreateMessageUtility("FisAppID/Name")

    static classes: any = {};
    static http: HttpService;

    static appname: string = "GraphQL Provider Application";

    constructor(public http: HttpService, public DPControllerInstance: DomainProxyController) {
        DataServiceManager.http = this.http;
        this.DPControllerInstance.setApplicationName(DataServiceManager.appname);
        let currentUCPId: string = "";

        let msg = this.DPControllerInstance.getMessageService().getLoginMessage();
        const settings: ConnectionInterface = {
            IdName: DataServiceManager.appname,
            Description: "GraphQL login",
            Type: "Http",
            Target: "http://swopt.com:3011",
        }
        msg.data["serviceProvider"] = {
            "name": 'GRAPHQL Server',
            "instanceId": generateId(),
            "secret": "FisSecret",
            "singleton": true,
            // "url": "http://" + IPs['v4'] + ":" + process.env.QueryModuleUrlPort
        }
        this.DPControllerInstance.setConnection(settings)
        let timer;
        const subscription = () => {
            this.DPControllerInstance.setIsConnectionStatusObserved(DataServiceManager.appname, true);
            this.DPControllerInstance.send(DataServiceManager.appname, msg).subscribe({
                // DataServiceManager.login(this.http).subscribe({
                next: (response) => {
                    // console.log(response.data?.['ServerUCP']?.ucpId)
                    if (response.data?.['ServerUCP']?.ucpId) {
                        currentUCPId = response.data?.['ServerUCP']?.ucpId;
                    }
                    else {
                        currentUCPId = null;
                    }

                    if (currentUCPId != null) {
                        // if (x.data[0]?.data?.ServerUCP?.ucpId !== undefined || x.data[0]?.data?.ucpId !== undefined) {

                        DataServiceManager.ucpId = currentUCPId


                        console.log(DataServiceManager.ucpId) // show the login ucpId

                        DataServiceManager.classes['AccountProfileDataService'] = new AccountProfileDataService(this.http, DataServiceManager.ucpId);
                        DataServiceManager.classes['APAccountProfileDataService'] = new APAccountProfileDataService(this.http, DataServiceManager.ucpId);
                        DataServiceManager.classes['ARAccountProfileDataService'] = new ARAccountProfileDataService(this.http, DataServiceManager.ucpId);
                        DataServiceManager.classes['CMAccountProfileDataService'] = new CMAccountProfileDataService(this.http, DataServiceManager.ucpId);

                        DataServiceManager.classes['DocumentDataService'] = new DocumentDataService(this.http, DataServiceManager.ucpId);
                        DataServiceManager.classes['ARInvoiceDocumentDataService'] = new ARInvoiceDocumentDataService(this.http, DataServiceManager.ucpId);
                        DataServiceManager.classes['APInvoiceDocumentDataService'] = new APInvoiceDocumentDataService(this.http, DataServiceManager.ucpId);

                        DataServiceManager.classes['ARReceiptDocumentDataService'] = new ARReceiptDocumentDataService(this.http, DataServiceManager.ucpId);
                        DataServiceManager.classes['APReceiptDocumentDataService'] = new APReceiptDocumentDataService(this.http, DataServiceManager.ucpId);


                        DataServiceManager.classes['OrganisationProfileDataService'] = new OrganisationProfileDataService(this.http, DataServiceManager.ucpId);
                        DataServiceManager.classes['ProductProfileDataService'] = new ProductProfileDataService(this.http, DataServiceManager.ucpId);
                        DataServiceManager.classes['ServiceProgramProfileDataService'] = new ServiceProgramProfileDataService(this.http, DataServiceManager.ucpId);
                        DataServiceManager.classes['FisServiceProgramProfileDataService'] = new FisServiceProgramProfileDataService(this.http, DataServiceManager.ucpId);
                        DataServiceManager.classes['RoleTypeProfileDataService'] = new RoleTypeProfileDataService(this.http, DataServiceManager.ucpId);
                        DataServiceManager.classes['LeaveBalanceDataService'] = new LeaveBalanceDataService(this.http, DataServiceManager.ucpId);
                        DataServiceManager.classes['LeaveHistoryDataService'] = new LeaveHistoryDataService(this.http, DataServiceManager.ucpId);
                        DataServiceManager.classes['LeaveTypeProfileDataService'] = new LeaveTypeProfileDataService(this.http, DataServiceManager.ucpId);
                        DataServiceManager.classes['FFBProductionDataService'] = new FFBProductionDataService(this.http, DataServiceManager.ucpId);
                        DataServiceManager.classes['FFBProductionSummaryDataService'] = new FFBProductionSummaryDataService(this.http, DataServiceManager.ucpId);

                        // Keep a copy of the class list
                        let dataServiceClassesList = JSON.stringify(DataServiceManager.classes, null, 4);
                        fs.writeFileSync('./src/FisAppQueryModule/dataservice.classesList.json', dataServiceClassesList); // To avoid confusion in src and dist
                        fs.writeFileSync('./dist/FisAppQueryModule/dataservice.classesList.json', dataServiceClassesList); // To avoid confusion in src and dist
                    } else if (response.data?.['StatusResponse'].status == '-1') {
                        console.log("Error getting ucpId")
                        console.log(response.data)
                        clearInterval(timer)
                        timer = setInterval(subscription, parseInt(process.env.FAILED_TIMEOUT))
                    }

                },

                complete: () => {
                    console.log("login done")
                    clearInterval(timer)
                    // timer = setInterval(subscription, parseInt(process.env.LOGIN_TIMEOUT))
                },
                error: (e) => {
                    console.log(e.response)
                    clearInterval(timer)
                    timer = setInterval(subscription, parseInt(process.env.FAILED_TIMEOUT))
                }
            })
        }

        timer = subscription()


    }



    getDataServiceData(ClassName, filter, returnFormatType = "full", gq, dynamicClassType = false): Observable<any> {
        let currentDataService: CommonDataService; // declare type 

        let bufferObservable = new Subject();

        if (!dynamicClassType) {
            currentDataService = DataServiceManager.classes[ClassName];
        } else {

            currentDataService = new CommonDataService(this.http, DataServiceManager.ucpId, DataServiceManager.classes[ClassName].currentData);


        }

        from(currentDataService.getData(ClassName, filter, returnFormatType)).subscribe({
            next: (msg: BaseMessage | ResponseMessage | ResponseExceptionMessage | any) => {
                if (msg && msg.header && msg.header.messageType == AppMessageType.ResponseException) {
                    this.DPControllerInstance.send(DataServiceManager.appname, msg).subscribe({
                        next: (msg: ResponseMessage) => {
                            bufferObservable.next(msg);
                            this.getDataServiceData(ClassName, filter, returnFormatType, gq, dynamicClassType)
                        }
                    });
                } else {
                    bufferObservable.next(msg);
                }
            },
            error: (err) => {
                bufferObservable.error(err);
            },
            complete: () => {
                bufferObservable.complete();
            }
        })

        return bufferObservable.asObservable();

    }


    static login(http) {
        if (!this.ResponseService) {
            this.ResponseService = new FisCreateMessageUtility('getLoginMessage');
        }

        try {
            const result = http.post(process.env.UCP_HOST, this.ResponseService.getLoginMessage())

            return result;
        } catch (e) {
            console.log(e)
            throw e;
        }


    }

    static logout(http) {
        console.log("ucpid: " + this.ucpId)
        if (!this.ResponseService) {
            this.ResponseService = new FisCreateMessageUtility('getLogoutMessage');
        }
        try {
            const result = http.post(process.env.UCP_HOST, {
                "id": "XXXXX",
                "message": this.ResponseService.getLogoutMessage(this.ucpId)
            })

            return result;


        } catch (e) {
            throw e;
        }
    }



    static metadata(http) {
        console.log("metadata ucpid: " + this.ucpId)
        if (!this.ResponseService) {
            this.ResponseService = new FisCreateMessageUtility('getCommandMessage_ext');
        }
        try {
            const result = http.post(process.env.UCP_HOST, {
                "id": "XXXXX",
                "message": this.ResponseService.getCommandMessage_ext(this.ucpId, 'GetMetadata', "Purchase Requisition"
                )
            })
            return result;
        } catch (e) {
            throw e;
        }
    }


}
function generateId(): string {
    let messageId = new Uuid();
    return messageId.generateId().toString();
}
