import { ArgsType, createUnionType, Field, Int, ObjectType } from '@nestjs/graphql';
import { Validate } from 'class-validator'; 

import { CustomFilter } from './CustomFilter.validate'; 
import { CustomReturnFormatType } from './CustomReturnFormatType.validate';

import {  SummaryResponse } from './DescendentDataServiceArgument.entity';

import { AccountProfile as AccountProfileType } from '../message/fisappmessagejsutility/interface/export';
import { StatusResponse } from './StatusResponse';

export const thisClassName = "AccountProfileDataService";

@ObjectType()
@ArgsType() 
export class AccountProfileArgument{

    public className: string = thisClassName;  
    
    @Field({ nullable: true })
    @Validate(CustomFilter)
    filter?: string; 

    @Field({ nullable: true })
    @Validate(CustomReturnFormatType)
    returnFormatType?: string;
}

@ObjectType()
@ArgsType() 
export class AccountProfileMessage { 

    
    @Field(type => [AccountProfile]) 
    data?: AccountProfile[]; 
    
}

@ObjectType()
@ArgsType() 
export class AccountProfile implements AccountProfileType {
    
    @Field(type=> Int, { nullable: true})
    acct_id: number;
  
    @Field(type=> Int, { nullable: true})
    orgn_id: number;

    @Field({ nullable: true})
    acct_dt_created: string;

    @Field({ nullable: true})
    acct_type: string;

    @Field(type=> Int, { nullable: true})
    acct_credit_balance: number;

    @Field(type=> Int, { nullable: true})
    acct_debit_balance: number;

    @Field(type=> Int, { nullable: true})
    prof_id: number;

    @Field({ nullable: true})
    acct_email_addr: string;

    @Field({ nullable: true})
    acct_dist_classification: string;

    @Field({ nullable: true})
    currency_code: string;

    @Field({ nullable: true})
    acct_full_name: string;

    @Field({ nullable: true})
    acct_no: string;

    @Field({ nullable: true})
    acct_nature: string;

    @Field({ nullable: true})
    acct_name: string;
    
}
    
@ObjectType()
@ArgsType() 
export class AccountProfileUnion {

    @Field(type=> SummaryResponse, { nullable: true})
    SummaryResponse?:SummaryResponse;

    @Field(type=> StatusResponse, { nullable: true})
    StatusResponse?:StatusResponse;

    @Field(type=> AccountProfileMessage, { nullable: true})
    AccountProfileMessage?:AccountProfileMessage
}

//  
