import { ArgsType, Field, Int, ObjectType } from '@nestjs/graphql';
import { SummaryResponse } from './DescendentDataServiceArgument.entity';
import { FFBProductionData as FFBProductionType } from '../message/fisappmessagejsutility/interface/export';
import { CustomFilter } from './CustomFilter.validate';
import { CustomReturnFormatType } from './CustomReturnFormatType.validate';
import { Validate } from 'class-validator'
import { StatusResponse } from './StatusResponse';


export const thisClassName = "FFBProductionDataService";

@ObjectType()
@ArgsType()
export class FFBProductionArgument {

    className: string = thisClassName;


    @Field({ nullable: true })
    @Validate(CustomFilter)
    filter?: string;

    @Field({ nullable: true })
    @Validate(CustomReturnFormatType)
    returnFormatType?: string;

}


@ObjectType()
@ArgsType()
export class FFBProductionMessage {

    @Field(type => [FFBProduction])
    data?: FFBProduction[];
}


@ObjectType()
@ArgsType()
export class FFBProduction implements FFBProductionType {


    @Field({ nullable: true })
    sec_code: string;

    @Field({ nullable: true })
    total_act_qty: string;

    @Field({ nullable: true })
    sumplanted: string;

    @Field({ nullable: true })
    sumunplanted: string;

    @Field({ nullable: true })
    orgn_full_name: string;

    @Field({ nullable: true })
    orgn_comp_reg_no: string;

    @Field({ nullable: true })
    orgn_address1: string;

    @Field({ nullable: true })
    orgn_address2: string;

    @Field({ nullable: true })
    orgn_address3: string;

    @Field({ nullable: true })
    wbc_date: string;

    @Field({ nullable: true })
    no_of_bunches: string;

    @Field({ nullable: true })
    tday: string;

    @Field(type => Int, { nullable: true })
    tyear: number;

    @Field(type => Int, { nullable: true })
    tmonth: number;


}


@ObjectType()
@ArgsType()
export class FFBProductionUnion {

    @Field(type => SummaryResponse, { nullable: true })
    SummaryResponse?: SummaryResponse;

    @Field(type => StatusResponse, { nullable: true })
    StatusResponse?: StatusResponse;

    @Field(type => FFBProductionMessage, { nullable: true })
    FFBProductionMessage?: FFBProductionMessage
}