import { ArgsType, Field, Int, ObjectType } from '@nestjs/graphql';
import { SummaryResponse } from './DescendentDataServiceArgument.entity';
import { FFBProductionSummary as FFBProductionSummaryType } from '../message/fisappmessagejsutility/interface/export';
import { CustomFilter } from './CustomFilter.validate';
import { CustomReturnFormatType } from './CustomReturnFormatType.validate';
import { Validate } from 'class-validator'
import { StatusResponse } from './StatusResponse';


export const thisClassName = "FFBProductionSummaryDataService";

@ObjectType()
@ArgsType()
export class FFBProductionSummaryArgument {

    className: string = thisClassName;


    @Field({ nullable: true })
    @Validate(CustomFilter)
    filter?: string;

    @Field({ nullable: true })
    @Validate(CustomReturnFormatType)
    returnFormatType?: string;

}


@ObjectType()
@ArgsType()
export class FFBProductionSummaryMessage {

    @Field(type => [FFBProductionSummary])
    data?: FFBProductionSummary[];
}


@ObjectType()
@ArgsType()
export class FFBProductionSummary implements FFBProductionSummaryType {


    @Field({ nullable: true })
    section_profile_sec_code: string;

    @Field(type => Int, { nullable: true })
    dmy_template_tyear: number;

    @Field(type => Int, { nullable: true })
    dmy_template_tmonth: number;

    @Field(type => Int, { nullable: true })
    dmy_template_tday: number;

    @Field({ nullable: true })
    sumplanted: string; // This is a number

    @Field({ nullable: true })
    sumunplanted: string; // This is a number

    @Field({ nullable: true })
    orgn_profile_company_v_orgn_full_name: string;

    @Field({ nullable: true })
    orgn_profile_company_v_orgn_comp_reg_no: string;

    @Field({ nullable: true })
    orgn_profile_company_v_orgn_address1: string;

    @Field({ nullable: true })
    orgn_profile_company_v_orgn_address2: string;

    @Field({ nullable: true })
    orgn_profile_company_v_orgn_address3: string;

    @Field({ nullable: true })
    wbc_date: string;

    @Field({ nullable: true })
    compute_1: string;

    @Field({ nullable: true })
    compute_2: string;

    @Field({ nullable: true })
    compute_3: string;

    @Field(type => Int, { nullable: true })
    no_of_bunches: number


}


@ObjectType()
@ArgsType()
export class FFBProductionSummaryUnion {

    @Field(type => SummaryResponse, { nullable: true })
    SummaryResponse?: SummaryResponse;

    @Field(type => StatusResponse, { nullable: true })
    StatusResponse?: StatusResponse;

    @Field(type => FFBProductionSummaryMessage, { nullable: true })
    FFBProductionSummaryMessage?: FFBProductionSummaryMessage
}