import { ArgsType, Field,  Int,  ObjectType } from '@nestjs/graphql';
import { Validate } from 'class-validator';
import { SummaryResponse } from './DescendentDataServiceArgument.entity';
import { FisServiceProgram as FisServiceProgramType } from '../message/fisappmessagejsutility/interface/export'
import { StatusResponse } from './StatusResponse';
import { CustomFilter } from './CustomFilter.validate';
import { CustomReturnFormatType } from './CustomReturnFormatType.validate';


export const thisClassName = "FisServiceProgramProfileDataService";

@ObjectType()
@ArgsType() 
export class FisServiceProgramProfileArgument {

    className: string = thisClassName; 
   
    @Field({ nullable: true })
    @Validate(CustomFilter)
    filter?: string; 

    @Field({ nullable: true })
    @Validate(CustomReturnFormatType)
    returnFormatType?: string;
}

@ObjectType()
@ArgsType() 
export class FisServiceProgramProfileMessage {
    

    @Field(type => [FisServiceProgramProfile]) 
    data?: FisServiceProgramProfile[];  

}


@ObjectType()
@ArgsType() 
export class FisServiceProgramProfile implements FisServiceProgramType{

    @Field(type=> Int,{ nullable: true})
    fisappserviceid: number;

    @Field({ nullable: true})
    serviceid: string;

    @Field({ nullable: true})
    servicename: string;
    
    @Field({ nullable: true})
    serviceprogram: string;

    @Field(type=> Int,{ nullable: true})
    servicetypeid: number;

    @Field({ nullable: true})
    servicetypecode: string;

    @Field({ nullable: true})
    servicetypedesc: string;

    @Field(type=> Int, { nullable: true})
    prg_id: number;

    @Field({ nullable: true})
    doc_type_id: string;

    @Field({ nullable: true})
    prg_startup_prg: string;

    @Field({ nullable: true})
    prg_name: string;

    @Field({ nullable: true})
    prg_desc: string;

    @Field({ nullable: true})
    prg_type: string;

    @Field({ nullable: true})
    prg_obj: string;

    @Field({ nullable: true})
    subs_code: string;

    @Field({ nullable: true})
    prg_others: string;

    @Field({ nullable: true})
    prg_display: string;

    @Field({ nullable: true})
    subs_name: string;

    @Field({ nullable: true})
    user_id: string;

    @Field({ nullable: true})
    user_code: string;

    @Field({ nullable: true})
    user_name: string;

    @Field({ nullable: true})
    orgn_id: string;

    @Field({ nullable: true})
    cannew: string;

    @Field({ nullable: true})
    canmodify: string;

    @Field({ nullable: true})
    candelete: string;

    @Field({ nullable: true})
    canread: string;

    @Field({ nullable: true})
    canverify: string;

    @Field({ nullable: true})
    canapprove: string;

    @Field({ nullable: true})
    cancommit: string;

    @Field({ nullable: true})
    canpost: string;

    @Field({ nullable: true})
    cancancel: string;

    @Field({ nullable: true})
    canvoid: string;

    @Field({ nullable: true})
    specialright: string
   
   
}

@ObjectType()
@ArgsType() 
export class FisServiceProgramUnion {

    @Field(type=> SummaryResponse, { nullable: true})
    SummaryResponse?:SummaryResponse;

    @Field(type=> StatusResponse, { nullable: true})
    StatusResponse?:StatusResponse;

    @Field(type=> FisServiceProgramProfileMessage, { nullable: true})
    FisServiceProgramProfileMessage?:FisServiceProgramProfileMessage
}