import { HttpService } from '@nestjs/axios';
import { Injectable } from '@nestjs/common';
import { map, Observable } from 'rxjs';

import { Site } from './entities/site.entity';

@Injectable()
export class SitesService {
  constructor(private readonly http: HttpService) {}

  result: any;
  /**
   * Retrieve multiple sites
   * @return {Site} - multiple site entity
   */
  findAllSite(): Observable<Site[]> {
    const observable = this.observableHttp(
      `http://${process.env.HOST}/site/api/sites`,
    );

    observable.subscribe({
      next: (x) => {
        this.result = x;
      },
      error: (err) => {
        console.log('Retrieve All Site Error : ' + err);
      },
      complete: () => {
        console.log('Done...');
      },
    });

    return this.result;
  }

  /**
   * Retrieve single site based on db
   * @params {db}
   * @return {Site} -  Site entity
   */
  findSite(db: string): Observable<Site[]> {
    const observable = this.observableHttp(
      `http://${process.env.HOST}/site/api/${db}/sites`,
    );

    observable.subscribe({
      next: (x) => {
        this.result = x;
      },
      error: (err) => {
        console.log('Retrieve All Site Error : ' + err);
      },
      complete: () => {
        console.log('Done...');
      },
    });

    return this.result;
  }




  observableHttp(...data): Observable<any> {
    return new Observable((subscriber) => {
      data.forEach((url) => {
        subscriber.next(
          this.http.get(url).pipe(map((response) => response.data)),
          // this.http.get(url),
        );
      });
      subscriber.complete();
    });
  }
}
